==> atf-0.5.tar.gz: atf-0.5/atf-c++/atffile.hpp <==
//
// Automated Testing Framework (atf)
//
// Copyright (c) 2007, 2008 The NetBSD Foundation, Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions
// are met:
// 1. Redistributions of source code must retain the above copyright
//    notice, this list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the following disclaimer in the
//    documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND
// CONTRIBUTORS ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
// INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
// IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS BE LIABLE FOR ANY
// DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
// GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
// IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
// OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
// IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//

#if !defined(_ATF_CXX_ATFFILE_HPP_)
#define _ATF_CXX_ATFFILE_HPP_

#include <string>
#include <vector>

#include <atf-c++/fs.hpp>
#include <atf-c++/tests.hpp>

namespace atf {

class atffile {
    atf::tests::vars_map m_conf;
    std::vector< std::string > m_tps;
    atf::tests::vars_map m_props;

public:
    atffile(const fs::path&);

    const atf::tests::vars_map& conf(void) const;
    const std::vector< std::string >& tps(void) const;
    const atf::tests::vars_map& props(void) const;
};

} // namespace atf

#endif // !defined(_ATF_CXX_ATFFILE_HPP_)

==> atf-0.8.tar.gz: atf-0.8/atf-c++/atffile.hpp <==
//
// Automated Testing Framework (atf)
//
// Copyright (c) 2007, 2008, 2010 The NetBSD Foundation, Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions
// are met:
// 1. Redistributions of source code must retain the above copyright
//    notice, this list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the following disclaimer in the
//    documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND
// CONTRIBUTORS ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
// INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
// IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS BE LIABLE FOR ANY
// DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
// GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
// IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
// OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
// IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//

#if !defined(_ATF_CXX_ATFFILE_HPP_)
#define _ATF_CXX_ATFFILE_HPP_

#include <string>
#include <vector>

#include <atf-c++/fs.hpp>
#include <atf-c++/tests.hpp>

namespace atf {
namespace atffile {

// ------------------------------------------------------------------------
// The "atffile" class.
// ------------------------------------------------------------------------

class atffile {
    atf::tests::vars_map m_conf;
    std::vector< std::string > m_tps;
    atf::tests::vars_map m_props;

public:
    atffile(const atf::tests::vars_map&,
            const std::vector< std::string >&,
            const atf::tests::vars_map&);

    const atf::tests::vars_map& conf(void) const;
    const std::vector< std::string >& tps(void) const;
    const atf::tests::vars_map& props(void) const;
};

// ------------------------------------------------------------------------
// Free functions.
// ------------------------------------------------------------------------

atffile read(const fs::path&);

} // namespace atffile
} // namespace atf

#endif // !defined(_ATF_CXX_ATFFILE_HPP_)
